import { ABORT } from '../consts.mjs';

/**
*
*
* 复制文件夹，并且支持模板文件
*
*  1. 支持深度复制文件夹，保持文件夹结构
*  2. 支持模板文件，模板文件以 .art 结尾，复制后去掉 .art后缀，采用art-template渲染
   3. 支持忽略文件或文件夹
   4. 支持文件或文件夹重命名
 
   copyFiles("/temp/a*.ts", targetDir, options)

*
*/

interface CopyFileInfo {
    file?: string;
    source?: string;
    target?: string;
    vars?: null | undefined | Record<string, any>;
}
interface CopyFilesOptions {
    vars?: Record<string, any> | ((file: string) => Record<string, any> | Promise<Record<string, any>>);
    ignore?: string[];
    clean?: boolean;
    cwd?: string;
    overwrite?: boolean | ((filename: string) => boolean | Promise<boolean>);
    before?: (info: CopyFileInfo) => void | typeof ABORT;
    after?: (info: CopyFileInfo) => void | typeof ABORT;
    error?: (error: Error, { source, target }: {
        source: string;
        target: string;
    }) => void | typeof ABORT;
    templateOptions?: Record<string, any> | ((file: string) => Record<string, any> | Promise<Record<string, any>>);
}
/**
 * 拷贝满足条件的文件到目标文件夹
 *
 * @param pattern
 * @param targetDir
 * @param options
 * @returns  返回实际拷贝的文件列表
 */
declare function copyFiles(pattern: string, targetDir: string, options?: CopyFilesOptions): Promise<string[]>;

export { type CopyFileInfo, type CopyFilesOptions, copyFiles };
