/**
 *
 * 初始化包工程
 *
 */
interface PackageInfo {
    name: string;
    version?: string;
    description?: string;
    author?: string;
    license?: string;
    main?: string;
    module?: string;
    types?: string;
    type?: "module" | "commonjs";
    scripts?: Record<string, string>;
    dependencies?: Record<string, string>;
    devDependencies?: Record<string, string>;
    peerDependencies?: Record<string, string>;
    optionalDependencies?: Record<string, string>;
    bundledDependencies?: Record<string, string>;
    [key: string]: any;
}
type DependencieType = 'dev' | 'prod' | 'peer' | 'optional' | 'bundle';
interface InitPackageOptions {
    location?: string;
    src?: string;
    typescript?: boolean | string;
    git?: boolean;
    dependencies?: (string | [string, DependencieType])[];
    silent?: boolean;
    onBeforeInstallDependent?: (packageName: string, installType: DependencieType) => void;
    onAfterInstallDependent?: (error: null | Error, packageName: string, installType: DependencieType) => void;
    installTool?: "auto" | "npm" | "yarn" | "pnpm";
    files?: (string | [string, string] | [string, string, Record<string, any>])[];
    onBeforeCopyFile?: (src: string, desc: string) => void;
    onAfterCopyFile?: (error: null | Error, src: string, desc: string) => void;
}
declare function initPackage(packageNameOrInfo: string | PackageInfo, options?: InitPackageOptions): Promise<PackageInfo>;

export { type DependencieType, type InitPackageOptions, type PackageInfo, initPackage };
