import { TreeNodeId, TreeNodeBase, TreeNode, TreeNodeOptions } from './types.js';

/**
 *
 * 将{id:any,children:[{},{},...,{}]}形式的树转换为[{id,pid,...},{id,pid,...},...,{id,pid,...}]的树结构
 *
 *
 */

interface ToPidTreeOptions<FromNode extends TreeNodeBase = TreeNode, ToNode extends TreeNodeBase = FromNode, IdKey extends string = 'id', ChildrenKey extends string = 'children', Path = string> extends TreeNodeOptions {
    includeLevel?: boolean;
    includePath?: boolean;
    mapper?: ({ node, level, parent, path, index }: {
        node: FromNode;
        level: number;
        parent?: FromNode | null;
        path: Path[];
        index: number;
    }) => Omit<ToNode, ChildrenKey | IdKey>;
}
type PidTreeNode<Node extends Record<string, any> = {
    [key: string]: any;
}, IdKey extends string = 'id', Path = string> = Node & TreeNodeId<IdKey, Node[IdKey]> & {
    pid: Node[IdKey] | null;
    level?: number;
    path?: Path[];
};
declare function toPidTree<FromNode extends TreeNodeBase = TreeNode, ToNode extends TreeNodeBase = FromNode, IdKey extends string = 'id', ChildrenKey extends string = 'children', Path = string>(treeObj: FromNode | FromNode[], options?: ToPidTreeOptions<FromNode, ToNode, IdKey, ChildrenKey, Path>): PidTreeNode<Omit<ToNode, ChildrenKey>, IdKey, Path>[];

export { type PidTreeNode, type ToPidTreeOptions, toPidTree };
