import { I as IForEachTreeCallback } from '../forEachTree-DC_vkeN0.mjs';
import { MoveTreeNodePosition } from './moveTreeNode.mjs';
import { SerachTreeOptions } from './searchTree.mjs';
import { TreeNodeBase, TreeNode, TreeNodeOptions } from './types.mjs';

interface FlexTreeOptions<Node extends TreeNodeBase = TreeNode, IdKey extends string = "id"> extends TreeNodeOptions {
    idGenerator(node: Partial<Node>): Node[IdKey];
}
declare class FlexTree<Node extends TreeNodeBase = TreeNode, IdKey extends string = "id", ChildrenKey extends string = "children"> {
    #private;
    constructor(nodes: Node[] | Node, options?: FlexTreeOptions<Node, IdKey>);
    get root(): Node | undefined;
    get nodes(): Node[];
    [Symbol.iterator](): {
        next: () => {
            value: Parameters<IForEachTreeCallback<Node>>[0];
            done: boolean;
        };
    };
    /**
     * 返回指定id的节点
     * @param nodeId
     * @returns
     */
    getNode(nodeId: Node[IdKey]): Node | null;
    addNode(nodeData: Partial<Node>, refNodeId: Node[IdKey], pos?: MoveTreeNodePosition): Node;
    removeNode(nodeId: Node[IdKey]): void;
    moveNode(nodeId: Node[IdKey], refNodeId: Node[IdKey], pos: MoveTreeNodePosition): void;
    /**
     * 搜索节点
     */
    search(matcher: IForEachTreeCallback<Node>, picker?: IForEachTreeCallback<Node>, options?: SerachTreeOptions): Node[][];
}

export { FlexTree, type FlexTreeOptions };
